@@ -2,8 +2,7 @@
 __init__.py : pylint_patcher top level
 """
 from ._version import __version__
-from .patcher import Patcher
 
-PATCHFILENAME = ".pylint-ignores.patch"
+PATCHFILENAME = ".pylint-disable.patch"
 
 
